![build workflow](https://github.com/CareBT/carebt_core/actions/workflows/python-app.yml/badge.svg)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# careBT - contingency aware Behavior Trees

## About

A Python library offering a Behavior Tree implementation which focuses on contingency handling - the key to
master complex applications which operate in dynamic worlds.

## Documentation

Documentation can be found at [https://carebt.readthedocs.io/](https://carebt.readthedocs.io/)

## Contacts

Andreas Steck - <steck.andi@gmail.com>
